@@ -22,7 +22,7 @@ package Net::FullAuto::ISets::Amazon::ClipBucket_is;
 #######################################################################
 
 our $VERSION='0.01';
-our $DISPLAY='CLIPBUCKET'
+our $DISPLAY='CLIPBUCKET';
 our $CONNECT='ssh';
 our $defaultInstanceType='t2.small';
 
@@ -732,7 +732,6 @@ END
          'admin_password' => $service_and_cert_password,
          'admin_password2' => $service_and_cert_password,
          'admin_email' => $verified_email,
-         'site_profile' => $site_profile,
          'submit' => 'Submit'
       ],
    );
@@ -853,10 +852,6 @@ END
 #END
    ($stdout,$stderr)=$handle->cmd(
       "${sudo}echo -e \"$config_email\" >> /var/www/clipbucket/config.php");
-);
-\\x24config['integration']['source'] = \'$site_name\';
-END
-   }
    ($stdout,$stderr)=$handle->cmd(
       "php /var/www/clipbucket/scripts/checkschema.php");
    print "\n   ACCESS GNU SOCIAL UI AT:\n\n",
